package com.ruoyi.frequency.auth.mapper;

import com.baomidou.mybatisplus.core.mapper.BaseMapper;
import com.ruoyi.frequency.auth.entity.Auth;
import com.ruoyi.frequency.auth.model.result.AuthCount;
import org.apache.ibatis.annotations.Param;

import java.util.List;

/**
 * 平台认证Mapper接口
 * 
 * @author liwenlong
 * @date 2023-10-18
 */
public interface AuthMapper  extends BaseMapper<Auth>
{
    /**
     * 查询平台认证
     * 
     * @param id 平台认证主键
     * @return 平台认证
     */
    public Auth selectAuthById(Long id);

    /**
     * 查询平台认证列表
     * 
     * @param auth 平台认证
     * @return 平台认证集合
     */
    public List<Auth> selectAuthList(Auth auth);

    /**
     * 新增平台认证
     * 
     * @param auth 平台认证
     * @return 结果
     */
    public int insertAuth(Auth auth);

    /**
     * 修改平台认证
     * 
     * @param auth 平台认证
     * @return 结果
     */
    public int updateAuth(Auth auth);

    /**
     * 删除平台认证
     * 
     * @param id 平台认证主键
     * @return 结果
     */
    public int deleteAuthById(Long id);

    /**
     * 批量删除平台认证
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteAuthByIds(Long[] ids);

    AuthCount statistics(@Param("list") List<Long> authIdList);
}
